@@ -7,17 +7,24 @@ pub enum MemoryState {
 }
 #[derive(Debug, Clone, Copy, PartialEq, Eq)]
 pub struct MemoryOp {
-    pub group: u32,
-    pub state: MemoryState,
+    group: u16,
+    state: MemoryState,
 }
 impl MemoryOp {
-    pub const fn new(group: u32, state: MemoryState) -> MemoryOp {
+    pub const fn new(group: usize, state: MemoryState) -> MemoryOp {
+        let group = group as u16;
         Self { group, state }
     }
+    pub fn group_same(&self, group: usize) -> bool {
+        self.group == group as u16
+    }
+    pub fn state(&self) -> MemoryState {
+        self.state
+    }
 }
 impl From<u32> for MemoryOp {
     fn from(src: u32) -> Self {
-        let group = (src & 0xFFFF_FFF0) >> 4;
+        let group = ((src & 0xFFFF_FFF0) >> 4) as u16;
         let state = match src & 0x0000_000F {
             1 => MemoryState::Writting,
             2 => MemoryState::Written,
@@ -29,7 +36,7 @@ impl From<u32> for MemoryOp {
 }
 impl From<MemoryOp> for u32 {
     fn from(src: MemoryOp) -> u32 {
-        (src.group << 4) | src.state as u32
+        ((src.group as u32) << 4) | src.state as u32
     }
 }
 
